import * as d3 from 'd3';

const data = {
  name: 'A1',
  children: [
    {
      name: 'B1',
      children: [
        {
          name: 'C1',
          value: 100,
        },
        {
          name: 'C2',
          value: 300,
        },
        {
          name: 'C3',
          value: 200,
        },
      ],
    },
    {
      name: 'B2',
      // value: 200,
      children: [
        {
          name: 'D1',
          value: 150,
        },
      ],
    },
  ],
};

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = d3
    .select(container)
    .selectAll('svg')
    .data([1])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .style('transform', `translate(${160}px, ${160}px)`);

  const radius = 150;
  const partitionLayout = d3
    .partition()
    .size([2 * Math.PI, radius]);

  const arcGenerator = d3
    .arc()
    .startAngle((d) => d.x0)
    .endAngle((d) => d.x1)
    .innerRadius((d) => d.y0)
    .outerRadius((d) => d.y1);

  const rootNode = d3.hierarchy(data);
  rootNode.sum((d) => d.value);

  partitionLayout(rootNode);

  svg
    .selectAll('path')
    .data(rootNode.descendants())
    .join('path')
    .attr('d', arcGenerator)
    .style('fill', '#333')
    .style('stroke', 'white')
    .style('opacity', 0.3);

  // svg
  //   .selectAll('text')
  //   .data(rootNode.descendants())
  //   .join('text')
  //   // .attr('dy', 14)
  //   .text((d) => d.data.name)
  //   .attr('x', (d) => d.x1)
  //   .attr('y', (d) => d.y1)
  //   .attr('text-anchor', 'middle');
};
